netapp_ontap.models.pool_health API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.pool_health`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class PoolHealthSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the PoolHealth object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `is_healthy: bool GET`

    Indicates whether the storage pool is able to participate in provisioning operations.

  `state: str GET`

    The state of the shared storage pool.

    Valid choices:

    - normal
    - degraded
    - creating
    - deleting
    - reassigning
    - growing
  `unhealthy_reason: Error GET`

    Indicates why the storage pool is unhealthy. This property is not returned for healthy storage pools.